@@ -108,7 +108,7 @@ create_work_group <- function(conn,
                               requester_pays = FALSE,
                               description = NULL,
                               tags = tag_options(key = NULL, value = NULL)){
-  if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+  con_error_msg(conn, "Connection already closed.")
   stopifnot(is.character(work_group),
             is.logical(enforce_work_group_config),
             is.logical(publish_cloud_watch_metrics),
@@ -125,8 +125,7 @@ create_work_group <- function(conn,
   request["Description"] <- list(description)
   request["Tags"] <- tags
   
-  Athena <- client_athena(conn)
-  tryCatch(do.call(Athena$create_work_group, request, quote = T),
+  tryCatch(do.call(conn@ptr$Athena$create_work_group, request, quote = T),
            error = function(e) py_error(e))
   invisible(NULL)
 }
@@ -142,11 +141,10 @@ tag_options <- function(key = NULL,
 #' @rdname work_group
 #' @export
 delete_work_group <- function(conn, work_group = NULL, recursive_delete_option = FALSE){
-  if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+  con_error_msg(conn, "Connection already closed.")
   stopifnot(is.character(work_group),
             is.logical(recursive_delete_option))
-  Athena <- client_athena(conn)
-  tryCatch(Athena$delete_work_group(WorkGroup = work_group, RecursiveDeleteOption = recursive_delete_option),
+  tryCatch(conn@ptr$Athena$delete_work_group(WorkGroup = work_group, RecursiveDeleteOption = recursive_delete_option),
            error = function(e) py_error(e))
   invisible(NULL)
 }
@@ -154,9 +152,8 @@ delete_work_group <- function(conn, work_group = NULL, recursive_delete_option =
 #' @rdname work_group
 #' @export
 list_work_groups <- function(conn){
-  if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
-  Athena <- client_athena(conn)
-  tryCatch(response <- Athena$list_work_groups(),
+  con_error_msg(conn, "Connection already closed.")
+  tryCatch(response <- conn@ptr$Athena$list_work_groups(),
            error = function(e) py_error(e))
   response[["WorkGroups"]]
 }
@@ -164,10 +161,9 @@ list_work_groups <- function(conn){
 #' @rdname work_group
 #' @export
 get_work_group <- function(conn, work_group = NULL){
-  if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+  con_error_msg(conn, "Connection already closed.")
   stopifnot(is.character(work_group))
-  Athena <- client_athena(conn)
-  tryCatch(response <- Athena$get_work_group(WorkGroup = work_group),
+  tryCatch(response <- conn@ptr$Athena$get_work_group(WorkGroup = work_group),
            error = function(e) py_error(e))
   response[["WorkGroup"]]
 }
@@ -183,7 +179,7 @@ update_work_group <- function(conn,
                               requester_pays = FALSE,
                               description = NULL,
                               state = c("ENABLED", "DISABLED")){
-  if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+  con_error_msg(conn, "Connection already closed.")
   stopifnot(is.character(work_group),
             is.logical(remove_output_location),
             is.logical(enforce_work_group_config),
@@ -203,8 +199,7 @@ update_work_group <- function(conn,
                                                             BytesScannedCutoffPerQuery = bytes_scanned_cut_off,
                                                             RequesterPaysEnabled = requester_pays))
   
-  Athena <- client_athena(conn)
-  tryCatch(do.call(Athena$update_work_group, request, quote = T),
+  tryCatch(do.call(conn@ptr$Athena$update_work_group, request, quote = T),
            error = function(e) py_error(e))
   invisible(NULL)
 }
@@ -274,9 +269,9 @@ get_session_token <- function(profile_name = NULL,
   # stop connection if region_name is not set in backend or hardcoded
   if(is.null(ptr$region_name)) stop("AWS `region_name` is required to be set. Please set `region` in .config file, ",
                                     "`AWS_REGION` in environment variables or `region_name` hard coded in function.", call. = FALSE)
+  sts <- ptr$client("sts")
   
-  tryCatch({sts <- ptr$client("sts")
-            response <- do.call(sts$get_session_token, args)},
+  tryCatch({response <- do.call(sts$get_session_token, args)},
            error = function(e) py_error(e))
   response$Credentials$Expiration <- py_to_r(response$Credentials$Expiration)
   if(set_env) {set_aws_env(response)}
@@ -336,8 +331,9 @@ assume_role <- function(profile_name = NULL,
   if(is.null(ptr$region_name)) stop("AWS `region_name` is required to be set. Please set `region` in .config file, ",
                                     "`AWS_REGION` in environment variables or `region_name` hard coded in function.", call. = FALSE)
   
-  tryCatch({sts <- ptr$client("sts")
-  response <- sts$assume_role(RoleArn = role_arn,
+  sts <- ptr$client("sts")
+  tryCatch({
+    response <- sts$assume_role(RoleArn = role_arn,
                               RoleSessionName = role_session_name,
                               DurationSeconds = as.integer(duration_seconds))},
   error = function(e) py_error(e))
