@@ -114,35 +114,32 @@ Athena_write_table <-
     if(!is.null(partition) && is.null(names(partition))) stop("partition parameter requires to be a named vector or list", call. = FALSE)
     if(!is.null(partition)) {names(partition) <- tolower(names(partition))}
     
-    if(!grepl("\\.", name)) name <- paste(conn@info$dbms.name, name, sep = ".") 
+    ll <- db_detect(conn, name)
+    db_name <- paste(ll, collapse = ".")
 
     if (overwrite && append) stop("overwrite and append cannot both be TRUE", call. = FALSE)
     
     # Check if table already exists in the database
-    found <- dbExistsTable(conn, name)
+    found <- dbExistsTable(conn, db_name)
     
     if (found && !overwrite && !append) {
-      stop("Table ", name, " exists in database, and both overwrite and",
+      stop("Table ", db_name, " exists in database, and both overwrite and",
            " append are FALSE", call. = FALSE)
     }
     
     if(!found && append){
-      stop("Table ", name, " does not exist in database and append is set to TRUE", call. = T)
+      stop("Table ", db_name, " does not exist in database and append is set to TRUE", call. = FALSE)
     }
     
     if (found && overwrite) {
-      dbRemoveTable(conn, name, confirm = TRUE)
+      dbRemoveTable(conn, db_name, confirm = TRUE)
     }
     
     # Check file format if appending
     if(found && append){
-      dbms.name <- gsub("\\..*", "" , name)
-      Table <- gsub(".*\\.", "" , name)
-      
-      glue <- conn@ptr$client("glue")
       tryCatch(
-              tbl_info <- glue$get_table(DatabaseName = dbms.name,
-                                         Name = Table)$Table,
+              tbl_info <- conn@ptr$glue$get_table(DatabaseName = ll[["dbms.name"]],
+                                         Name = ll[["table"]])$Table,
               error = function(e) py_error(e))
       
       # Return correct file format when appending onto existing AWS Athena table
@@ -155,7 +152,7 @@ Athena_write_table <-
                          # json library support: https://docs.aws.amazon.com/athena/latest/ug/json.html#hivejson
                          "org.apache.hive.hcatalog.data.JsonSerDe" = "json",
                          "org.openx.data.jsonserde.JsonSerDe" = "json",
-                         stop("Unable to append onto table: ", name,"\n", tbl_info$StorageDescriptor$SerdeInfo$SerializationLibrary,
+                         stop("Unable to append onto table: ", db_name,"\n", tbl_info$StorageDescriptor$SerdeInfo$SerializationLibrary,
                               ": Is currently not supported by RAthena", call. = F))
 
       # Return if existing files are compressed or not
@@ -211,10 +208,10 @@ Athena_write_table <-
     ############# update data to aws s3 ###########################
     
     # send data over to s3 bucket
-    upload_data(conn, FileLocation, name, partition, s3.location, file.type, compress, append)
+    upload_data(conn, FileLocation, db_name, partition, s3.location, file.type, compress, append)
     
     if (!append) {
-      sql <- sqlCreateTable(conn, table = name, fields = value, field.types = field.types, 
+      sql <- sqlCreateTable(conn, table = db_name, fields = value, field.types = field.types, 
                             partition = names(partition),
                             s3.location = s3.location, file.type = file.type,
                             compress = compress)
@@ -224,7 +221,7 @@ Athena_write_table <-
       dbClearResult(rs)}
     
     # Repair table
-    repair_table(conn, name, partition, s3.location, append)
+    repair_table(conn, db_name, partition, s3.location, append)
     
     on.exit({lapply(FileLocation, unlink)
       if(!is.null(conn@info$expiration)) time_check(conn@info$expiration)})
@@ -247,10 +244,9 @@ upload_data <- function(conn, x, name, partition = NULL, s3.location= NULL,  fil
   FileName <- paste(uuid::UUIDgenerate(n = length(x)),  FileType, sep = ".")
   s3_key <- paste(s3_key, FileName, sep = "/")
   
-  tryCatch(s3 <- conn@ptr$resource("s3"),
-           error = function(e) py_error(e))
   for (i in 1:length(x)){
-    retry_api_call(s3$Bucket(Bucket)$upload_file(Filename = x[i], Key = s3_key[i]))}
+    retry_api_call(
+      conn@ptr$S3$upload_file(x[i], Bucket, s3_key[i]))}
   
   invisible(NULL)
 }
@@ -264,7 +260,7 @@ setMethod(
            row.names = NA, field.types = NULL, 
            partition = NULL, s3.location = NULL, file.type = c("tsv","csv", "parquet","json"),
            compress = FALSE, max.batch = Inf, ...){
-    if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+    con_error_msg(conn, msg = "Connection already closed.")
     Athena_write_table(conn, name, value, overwrite, append,
                       row.names, field.types,
                       partition, s3.location, file.type, compress, max.batch)
@@ -278,7 +274,7 @@ setMethod(
            row.names = NA, field.types = NULL, 
            partition = NULL, s3.location = NULL, file.type = c("tsv","csv", "parquet","json"),
            compress = FALSE, max.batch = Inf, ...){
-    if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+    con_error_msg(conn, msg = "Connection already closed.")
     Athena_write_table(conn, name, value, overwrite, append,
                       row.names, field.types,
                       partition, s3.location, file.type, compress, max.batch)
@@ -292,7 +288,7 @@ setMethod(
            row.names = NA, field.types = NULL, 
            partition = NULL, s3.location = NULL, file.type = c("tsv","csv", "parquet","json"),
            compress = FALSE, max.batch = Inf,...){
-    if (!dbIsValid(conn)) {stop("Connection already closed.", call. = FALSE)}
+    con_error_msg(conn, msg = "Connection already closed.")
     Athena_write_table(conn, name, value, overwrite, append,
                       row.names, field.types,
                       partition, s3.location, file.type, compress, max.batch)
@@ -408,7 +404,7 @@ NULL
 setMethod("sqlCreateTable", "AthenaConnection",
   function(con, table, fields, field.types = NULL, partition = NULL, s3.location= NULL, file.type = c("tsv","csv", "parquet","json"), 
            compress = FALSE, ...){
-    if (!dbIsValid(con)) {stop("Connection already closed.", call. = FALSE)}
+    con_error_msg(con, msg = "Connection already closed.")
     stopifnot(is.character(table),
               is.data.frame(fields),
               is.null(field.types) || is.character(field.types),
@@ -422,22 +418,15 @@ setMethod("sqlCreateTable", "AthenaConnection",
     # use default s3_staging directory is s3.location isn't provided
     if (is.null(s3.location)) s3.location <- con@info$s3_staging
     
-    if (grepl("\\.", table)) {
-      schema <- gsub("\\..*", "" , table)
-      table1 <- gsub(".*\\.", "" , table)
-    } else {
-      schema <- con@info$dbms.name
-      table1 <- table}
+    ll <- db_detect(con, table)
     
     # create s3 location
     s3_location <- s3_upload_location(con, s3.location, table, NULL, FALSE)
     s3_location <- Filter(Negate(is.null), s3_location)
     s3_location <- sprintf("'s3://%s/'", paste(s3_location,collapse = "/"))
     
-    table <- paste0(quote_identifier(con,  c(schema,table1)), collapse = ".")
+    table <- paste0(quote_identifier(con,  c(ll[["dbms.name"]],ll[["table"]])), collapse = ".")
     
-    if(grepl(table1, s3.location)){s3.location <- gsub(paste0("/", table1,"$"), "", s3.location)}
-    s3.location <- paste0("'",s3.location,"/",schema,"/", table1,"/'")
     SQL(paste0(
       "CREATE EXTERNAL TABLE ", table, " (\n",
       "  ", paste(field, collapse = ",\n  "), "\n)\n",
@@ -522,12 +511,9 @@ quote_identifier <- function(conn, x, ...) {
 # moved s3 component builder to separate helper function to allow for unit tests
 s3_upload_location <- function(con, s3.location = NULL, name = NULL, partition = NULL, append = FALSE){
   # Get schema and name
-  if (grepl("\\.", name)) {
-    schema <- gsub("\\..*", "" , name)
-    name <- gsub(".*\\.", "" , name)
-  } else {
-    schema <- con@info$dbms.name
-    name <- name}
+  ll <- db_detect(con, name)
+  schema <- ll[["dbms.name"]]
+  name <- ll[["table"]]
   
   # s3 bucket and key split
   s3_info <- split_s3_uri(s3.location)
@@ -562,15 +548,10 @@ s3_upload_location <- function(con, s3.location = NULL, name = NULL, partition =
 
 # repair table using MSCK REPAIR TABLE for non partitioned and ALTER TABLE for partitioned tables
 repair_table <- function(con, name, partition = NULL, s3.location = NULL, append = FALSE){
-  if (grepl("\\.", name)) {
-    schema <- gsub("\\..*", "" , name)
-    table1 <- gsub(".*\\.", "" , name)
-  } else {
-    schema <- con@info$dbms.name
-    table1 <- name}
+  ll <- db_detect(con, name)
   
   # format table name for special characters
-  table <- paste0(quote_identifier(con,  c(schema,table1)), collapse = ".")
+  table <- paste0(quote_identifier(con,  c(ll[["dbms.name"]], ll[["table"]])), collapse = ".")
   
   if (is.null(partition)){
     query <- SQL(paste0("MSCK REPAIR TABLE ", table))
@@ -589,17 +570,19 @@ repair_table <- function(con, name, partition = NULL, s3.location = NULL, append
     
     query <- SQL(paste0("ALTER TABLE ", table, " ADD IF NOT EXISTS\nPARTITION (", partition, ")\nLOCATION ", s3_location))
     res <- dbSendQuery(con, query)
-    poll_result <- poll(res)
-    dbClearResult(res)
+    poll(res)
+    on.exit(dbClearResult(res))
     
     # If query failed, due to glue permissions default back to msck repair table
-    if(poll_result$QueryExecution$Status$State == "FAILED" && 
-       grepl(".*glue.*BatchCreatePartition.*AccessDeniedException", 
-             poll_result$QueryExecution$Status$StateChangeReason)) {
-      query <- SQL(paste0("MSCK REPAIR TABLE ", table))
-      res <- dbExecute(con, query)
-      dbClearResult(res)
-    } else if (poll_result$QueryExecution$Status$State == "FAILED")
-        stop(poll_result$QueryExecution$Status$StateChangeReason, call. = FALSE)
+    if(res@info[["Status"]] == "FAILED") {
+      
+      if(grepl(".*glue.*BatchCreatePartition.*AccessDeniedException", 
+               res@info[["StateChangeReason"]])){
+        query <- SQL(paste0("MSCK REPAIR TABLE ", table))
+        rs <- dbExecute(con, query)
+        return(dbClearResult(rs))}
+      
+      stop(res@info[["StateChangeReason"]], call. = FALSE)
+    }
   }
 }
