@@ -26,16 +26,7 @@ is.s3_uri <- function(x) {
 poll <- function(res){
   tryCatch(
     .poll(res),
-    interrupt = function(i){
-      if(res@connection@info$keyboard_interrupt){
-        dbClearResult(res)
-        stop(sprintf("Query '%s' has been cancelled by user.", res@info[["QueryExecutionId"]]), call. = F)
-      } else {
-        stop(
-          sprintf("Query '%s' has been cancelled by user but will carry on running in AWS Athena",
-                  res@info[["QueryExecutionId"]]), call. = F)
-      }
-    }
+    interrupt = function(i) interrupt_athena(res)
   )
 }
 
@@ -48,7 +39,6 @@ poll <- function(res){
              error = function(e) py_error(e))
     if (query_execution$QueryExecution$Status$State %in% c("SUCCEEDED", "FAILED", "CANCELLED")){
       # update info environment
-      res@info[["Query"]] <- query_execution[["QueryExecution"]][["Query"]]
       res@info[["Status"]] <- query_execution[["QueryExecution"]][["Status"]][["State"]]
       res@info[["StateChangeReason"]] <- query_execution[["QueryExecution"]][["Status"]][["StateChangeReason"]]
       res@info[["StatementType"]] <- query_execution[["QueryExecution"]][["StatementType"]]
@@ -60,6 +50,20 @@ poll <- function(res){
   }
 }
 
+interrupt_athena <- function(res){
+  if(res@connection@info[["keyboard_interrupt"]]){
+    msg = sprintf(
+      "Query '%s' has been cancelled by user.",
+      res@info[["QueryExecutionId"]])
+    dbClearResult(res)
+  } else {
+    msg = sprintf(
+      "Query '%s' has been cancelled by user but will carry on running in AWS Athena",
+      res@info[["QueryExecutionId"]])
+  }
+  stop(msg, call. = F)
+}
+
 # added a random poll wait time
 rand_poll <- function() {runif(n = 1, min = 50, max = 100) / 100}
 
